Skip to contents

Compute the constant \(d_2\), the expected value of the relative range \(W = R / \sigma\) for a sample of size \(n\) drawn from a normal distribution, where \(R\) is the sample range and \(\sigma\) is the process standard deviation.

Usage

d2(n)

Arguments

n

Integer sample size, at least 2. Can be a vector.

Value

Numeric vector of \(d_2\) values, the same length as n.

Details

Under normality, \(W\) has the studentized range distribution with infinite denominator degrees of freedom. Its expectation is the integral of the survival function, \(E[W] = \int_0^\infty \{1 - F_W(w)\} dw\), which is evaluated numerically using ptukey with infinite degrees of freedom.

References

Montgomery, D. C. (2009). Introduction to Statistical Quality Control, 6th ed. Wiley.

Barbosa, E. P., Gneri, M. A. and Meneguetti, A. (2013). Range control charts revisited: Simpler Tippett-like formulae, its practical implementation, and the study of false alarm. Communications in Statistics - Simulation and Computation, 42(2), 247–262. doi:10.1080/03610918.2011.639967 .

See also

Author

Daniela R. Recchia, Emanuel P. Barbosa

Examples


d2(5)
#> [1] 2.325929
d2(2:10)
#> [1] 1.128379 1.692569 2.058751 2.325929 2.534413 2.704357 2.847201 2.970026
#> [9] 3.077505