Learn R Programming

IQCC (version 0.7)

pistonrings: Piston Rings Data Set.

Description

The Piston Rings data set was taken from Montgomery's book. It consists of 40 samples of size 5 each of values of the diameter of the piston rings.

Arguments

Format

A data frame with 40 observations on the following 5 variables.

V1

The fisrt measure.

V2

The second measure.

V3

The third measure.

V4

The fouth measure.

V5

The fifth measure.

Examples

Run this code
# NOT RUN {
data(pistonrings)

# }

Run the code above in your browser using DataLab