Learn R Programming

IQCC (version 0.7)

T2.1: Hotelling T2 Statistic for Phase I.

Description

Calculate the Hotelling T2 statistic for multivariate observations at phase I , to be used to build the corresponding control chart.

Usage

T2.1(estat, m, n)

Arguments

estat

The values of the auxiliary statistics. Should be a list with a matrix with the means, mean of the means and mean of the standard deviation.

m

The number of samples generated previously in data.1.

n

The size of each samples used previously in data.1.

Value

Return a vector with the Hotelling T2 statistics.

Details

Before using this function it is necessary to execute the function "stats"(that calculate the auxiliary statistics involved in the T2 formula) and the function "data.1" (or other way to supply the data).

References

Montgomery, D.C.,(2008)."Introduction to Statistical Quality Control". Chapter 11. Wiley.

See Also

stats, data.1, cchart.T2.1

Examples

Run this code
# NOT RUN {
mu <- c(5.682, 88.22)
Sigma <- symMatrix(c(3.770, -5.495, 13.53), 2)
#Example with individual observations
datum <- data.1(50, 1, mu, Sigma)
estat <- stats(datum, 50, 1, 2) 
T2.1(estat, 50, 1)
#Example with sub group observations
datum <- data.1(20, 10, mu, Sigma)
estat <- stats(datum, 20, 10, 2) 
T2.1(estat, 20, 10)

# }

Run the code above in your browser using DataLab