Used to calculate the real probability of false alarm in the 3-sigma R chart.

alpha.risk(n)

Arguments

n

The sample size. Can be a vector for multiple sample sizes.

Value

Return a vector of alpha risk values for the given sample sizes.

Details

This alpha risk is calculated under the exact R statistics distribution and its values for small sample sizes will be much larger than the reference value 0,0027.

See also

Author

Daniela R. Recchia, Emanuel P. Barbosa

Examples


alpha.risk(15)
#> [1] 0.004493839