Used to calculate the real probability of false alarm in the 3-sigma R chart.
alpha.risk(n)Return a vector of alpha risk values for the given sample sizes.
This alpha risk is calculated under the exact R statistics distribution and its values for small sample sizes will be much larger than the reference value 0,0027.
alpha.risk(15)
#> [1] 0.004493839