Learn R Programming

IQCC (version 0.7)

alpha.risk: False Alarm probability for the 3-sigma R chart.

Description

Used to calculate the real probability of false alarm in the 3-sigma R chart.

Usage

alpha.risk(n)

Arguments

n

The sample size.

Value

Return the value of the alpha risk for a given sample size n.

Details

This alpha risk is calculated under the exact R statistics distribution and its values for small sample sizes will be much larger than the reference value 0,0027.

See Also

d2,d3,c4

Examples

Run this code
# NOT RUN {
alpha.risk(15)

# }

Run the code above in your browser using DataLab