This function is used to calculate the bias correction constant c4 for the sample standard deviation statistic.

c4(n)

Arguments

n

The sample size.

Value

Return the value of c4 for a given sample size n.

Details

It is used to correct the bias for small sample sizes in the sample standard deviation statistic.

See also

Author

Daniela R. Recchia, Emanuel P. Barbosa

Examples


c4(5)
#> [1] 0.9399856