Learn R Programming

IQCC (version 0.7)

c4: C4 Constant.

Description

This function is used to calculate the bias correction constant c4 for the sample standard deviation statistic.

Usage

c4(n)

Arguments

n

The sample size.

Value

Return the value of c4 for a given sample size n.

Details

It is used to correct the bias for small sample sizes in the sample standard deviation statistic.

See Also

d2,d3

Examples

Run this code
# NOT RUN {
c4(5)

# }

Run the code above in your browser using DataLab