powered by
This function is used to calculate the bias correction constant c4 for the sample standard deviation statistic.
c4(n)
The sample size.
Return the value of c4 for a given sample size n.
It is used to correct the bias for small sample sizes in the sample standard deviation statistic.
d2,d3
# NOT RUN { c4(5) # }
Run the code above in your browser using DataLab