A character string specifying the type of S control chart to be
plotted where "n" plots a S chart with normalized probability limits and "e"
plots a S chart with exact limits.
m
The sample sizes. Only necessary in the control chart with exact
(probability) limits.
Value
Return a S control chart.
Details
The exact limits are the alpha/2 and 1-alpha/2 quantiles of the S
distribution which is proportional to the square root of a chi-square
distribution.
# NOT RUN {data(softdrink)
#S chart with normalized probability limitscchart.S(softdrink, type = "n")
#S chart with exact probability limitscchart.S(softdrink, type = "e", 10)
# }