powered by
Builds the x-bar control chart for phase II.
cchart.Xbar2(x, x2bar, sigma, sizes)
The data to be plotted.
The mean of means.
The standar deviation of the data.
A value or a vector of values specifying the sample sizes associated with each group.
Return a x-bar control chart for phase II.
To use this function it is necessary to have the output given by the function XbarI.
cchart.Xbar1
# NOT RUN { data(pistonrings) stat <- cchart.Xbar1(pistonrings[1:25, ]) cchart.Xbar2(pistonrings[26:40, ], stat[[1]][1], stat[[1]][2]) # }
Run the code above in your browser using DataLab