Learn R Programming

IQCC (version 0.7)

cchart.Xbar_R: X-bar and R control charts

Description

This function builds the X-bar and R control charts in the same window.

Usage

cchart.Xbar_R(x, sizes)

Arguments

x

The data to be plotted.

sizes

A value or a vector of values specifying the sample sizes associated with each group.

Value

Return the two control charts.

Examples

Run this code
# NOT RUN {
data(pistonrings)
attach(pistonrings)
cchart.Xbar_R(pistonrings[1:25, ])

# }

Run the code above in your browser using DataLab