powered by
This function builds the X-bar and R control charts in the same window.
cchart.Xbar_R(x, sizes)
The data to be plotted.
A value or a vector of values specifying the sample sizes associated with each group.
Return the two control charts.
# NOT RUN { data(pistonrings) attach(pistonrings) cchart.Xbar_R(pistonrings[1:25, ]) # }
Run the code above in your browser using DataLab