Learn R Programming

IQCC (version 0.7)

data.1: Hotelling Control Chart Phase I simulated data.

Description

This function simulate a normal data set to be used in the phase I Hoteliing control charts.

Usage

data.1(m, n, mu, Sigma)

Arguments

m

The number of samples to be generated.

n

The size of each sample. If they are individual observations, then use n = 1.

mu

The vector with the means of the data to be generated.

Sigma

The vector with the variance-covariance matrix of the data to be generated.

Value

Return an array with the simulated data.

See Also

data.2

Examples

Run this code
# NOT RUN {
mu <- c(5.682, 88.22)
Sigma <- symMatrix(c(3.770, -5.495, 13.53), 2)
#Simulated data with individual observations
datum <- data.1(50, 1, mu, Sigma)
#Simulated data with sub-group observations
datum <- data.1(20, 10, mu, Sigma)

# }

Run the code above in your browser using DataLab