This function simulate a normal data set to be used in the phase II Hotelling control charts.
data.2(estat, n, delta = 0, p)The values of the auxiliary statistics. Should be a list with the mean of means, the average variance-covariance matrix, and a matrix with the means of each sample.
The size of each sample. If they are individual observations, use n = 1.
A value to be added on the vector of means.
The dimension.
Return an array with the simulated data.
To use this function it is necessary to have the information about the phase I given by the functions data.1 and stats.