powered by
The Piston Rings data set was taken from Montgomery's book. It consists of 40 samples of size 5 each of values of the diameter of the piston rings.
A data frame with 40 observations on the following 5 variables.
The fisrt measure.
The second measure.
The third measure.
The fouth measure.
The fifth measure.
# NOT RUN { data(pistonrings) # }
Run the code above in your browser using DataLab