Plot first-stage and second-stage DS-np decisions on separate panels so that the first-stage count and combined count are shown on their proper scales.
Usage
# S3 method for class 'cchart.DSnp'
plot(x, ...)Plot first-stage and second-stage DS-np decisions on separate panels so that the first-stage count and combined count are shown on their proper scales.
# S3 method for class 'cchart.DSnp'
plot(x, ...)