Builds a table with quantiles of the sample relative range distribution.
Usage
table.qtukey(alpha, n)
Arguments
alpha
The probability of type-I error of false alarm , that is equal
to 1 minus the confidence level.
n
The maximum sample size.
Value
It is used the fact that the sample relative range distribution is
the same as the sample studentized range distribution (tukey distribution)
with infinity d.f. in the denominator . It is considered 4 quantiles:
alpha/2 , alpha , 1-alpha and 1-alpha/2, for different sample size values .